@@ -14,6 +14,5 @@
 
 """Public-facing Warlock API"""
 
-# pylint: disable=W0611
-from warlock.core import model_factory
-from warlock.exceptions import InvalidOperation
+from warlock.core import model_factory  # NOQA
+from warlock.exceptions import InvalidOperation  # NOQA
